package com.project.zcustom.mapper.logistics;

import com.baomidou.mybatisplus.annotation.InterceptorIgnore;
import com.project.zcustom.domain.addional.LargeAssetDirs;
import com.project.zcustom.domain.addional.LargeLogistics;

import java.util.List;
import java.util.Map;

@InterceptorIgnore(blockAttack = "true")
public interface PlatAssetMapper {

    public int deleteLogistics();

    public int deleteOfficeAssetDirs();

    public int deleteBuildingAssetDirs();

    public int deleteServiceAssetDirs();

    public int insertLargePlatLogistics(List<LargeLogistics> largeLogisticsList);

    public int insertOfficeAssetDirs(List<LargeAssetDirs> largeAssetDirsList);

    public int insertBuildingAssetDirs(List<LargeAssetDirs> largeAssetDirsList);

    public int insertServiceAssetDirs(List<LargeAssetDirs> largeAssetDirsList);



    public List<LargeAssetDirs> getBuildingAssetRate(String appOrg);

    public Long getBuildingAssetNum(String appOrg);

    public List<LargeAssetDirs> getServiceAssetRate(String appOrg);

    public Long getServiceAssetNum(String appOrg);

    public List<LargeAssetDirs> getOfficeAssetRate(String appOrg);

    public Long getOfficeAssetNum(String appOrg);



    public LargeLogistics getStockAssetNum(String appOrg);

    public LargeLogistics getNewAssetNum(String appOrg);

    public LargeLogistics getScrapAssetNum(String appOrg);



    public Map<String, Object> getCodedAndLabelRate(String appOrg);

    public LargeLogistics getMainlyRate(String appOrg);



    public List<LargeLogistics> getSceneRateX();

    public List<LargeLogistics> getSceneRateY();

    public LargeLogistics getOperation(String appOrg);

    public List<LargeLogistics> getInspectionSchemeNumX();

    public List<LargeLogistics> getInspectionSchemeNumY();
}
